@@ -1,4 +1,5 @@
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
+
 
 urlpatterns = patterns('tokenapi.views',
     url(r'^token/new.json$', 'token_new', name='api_token_new'),
